# Auto-generated. Do not modify, use scripts/generate_langs.py instead.
AFRIKAANS = "Afrikaans"
AMHARIC = "Amharic"
ARABIC = "Arabic"
ASTURIAN = "Asturian"
AZERBAIJANI = "Azerbaijani"
BASHKIR = "Bashkir"
BELARUSIAN = "Belarusian"
BULGARIAN = "Bulgarian"
BENGALI = "Bengali"
BRETON = "Breton"
BOSNIAN = "Bosnian"
CATALAN = "Catalan"
VALENCIAN = "Valencian"
CEBUANO = "Cebuano"
CZECH = "Czech"
WELSH = "Welsh"
DANISH = "Danish"
GERMAN = "German"
GREEK = "Greek"
ENGLISH = "English"
SPANISH = "Spanish"
ESTONIAN = "Estonian"
PERSIAN = "Persian"
FULAH = "Fulah"
FINNISH = "Finnish"
FRENCH = "French"
WESTERN_FRISIAN = "Western Frisian"
IRISH = "Irish"
GAELIC = "Gaelic"
SCOTTISH_GAELIC = "Scottish Gaelic"
GALICIAN = "Galician"
GUJARATI = "Gujarati"
HAUSA = "Hausa"
HEBREW = "Hebrew"
HINDI = "Hindi"
CROATIAN = "Croatian"
HAITIAN = "Haitian"
HAITIAN_CREOLE = "Haitian Creole"
HUNGARIAN = "Hungarian"
ARMENIAN = "Armenian"
INDONESIAN = "Indonesian"
IGBO = "Igbo"
ILOKO = "Iloko"
ICELANDIC = "Icelandic"
ITALIAN = "Italian"
JAPANESE = "Japanese"
JAVANESE = "Javanese"
GEORGIAN = "Georgian"
KAZAKH = "Kazakh"
CENTRAL_KHMER = "Central Khmer"
KANNADA = "Kannada"
KOREAN = "Korean"
LUXEMBOURGISH = "Luxembourgish"
LETZEBURGESCH = "Letzeburgesch"
GANDA = "Ganda"
LINGALA = "Lingala"
LAO = "Lao"
LITHUANIAN = "Lithuanian"
LATVIAN = "Latvian"
MALAGASY = "Malagasy"
MACEDONIAN = "Macedonian"
MALAYALAM = "Malayalam"
MONGOLIAN = "Mongolian"
MARATHI = "Marathi"
MALAY = "Malay"
BURMESE = "Burmese"
NEPALI = "Nepali"
DUTCH = "Dutch"
FLEMISH = "Flemish"
NORWEGIAN = "Norwegian"
NORTHERN_SOTHO = "Northern Sotho"
OCCITAN = "Occitan"
ORIYA = "Oriya"
PANJABI = "Panjabi"
PUNJABI = "Punjabi"
POLISH = "Polish"
PUSHTO = "Pushto"
PASHTO = "Pashto"
PORTUGUESE = "Portuguese"
ROMANIAN = "Romanian"
MOLDAVIAN = "Moldavian"
MOLDOVAN = "Moldovan"
RUSSIAN = "Russian"
SINDHI = "Sindhi"
SINHALA = "Sinhala"
SINHALESE = "Sinhalese"
SLOVAK = "Slovak"
SLOVENIAN = "Slovenian"
SOMALI = "Somali"
ALBANIAN = "Albanian"
SERBIAN = "Serbian"
SWATI = "Swati"
SUNDANESE = "Sundanese"
SWEDISH = "Swedish"
SWAHILI = "Swahili"
TAMIL = "Tamil"
THAI = "Thai"
TAGALOG = "Tagalog"
TSWANA = "Tswana"
TURKISH = "Turkish"
UKRAINIAN = "Ukrainian"
URDU = "Urdu"
UZBEK = "Uzbek"
VIETNAMESE = "Vietnamese"
WOLOF = "Wolof"
XHOSA = "Xhosa"
YIDDISH = "Yiddish"
YORUBA = "Yoruba"
CHINESE = "Chinese"
ZULU = "Zulu"



# Auto-generated. Do not modify, use scripts/generate_langs.py instead.
ARABIC = "Arabic"
CZECH = "Czech"
GERMAN = "German"
ENGLISH = "English"
SPANISH = "Spanish"
ESTONIAN = "Estonian"
FINNISH = "Finnish"
FRENCH = "French"
GUJARATI = "Gujarati"
HINDI = "Hindi"
ITALIAN = "Italian"
JAPANESE = "Japanese"
KAZAKH = "Kazakh"
KOREAN = "Korean"
LITHUANIAN = "Lithuanian"
LATVIAN = "Latvian"
BURMESE = "Burmese"
NEPALI = "Nepali"
DUTCH = "Dutch"
ROMANIAN = "Romanian"
RUSSIAN = "Russian"
SINHALA = "Sinhala"
TURKISH = "Turkish"
VIETNAMESE = "Vietnamese"
CHINESE = "Chinese"
AFRIKAANS = "Afrikaans"
AZERBAIJANI = "Azerbaijani"
BENGALI = "Bengali"
PERSIAN = "Persian"
HEBREW = "Hebrew"
CROATIAN = "Croatian"
INDONESIAN = "Indonesian"
GEORGIAN = "Georgian"
KHMER = "Khmer"
MACEDONIAN = "Macedonian"
MALAYALAM = "Malayalam"
MONGOLIAN = "Mongolian"
MARATHI = "Marathi"
POLISH = "Polish"
PASHTO = "Pashto"
PORTUGUESE = "Portuguese"
SWEDISH = "Swedish"
SWAHILI = "Swahili"
TAMIL = "Tamil"
TELUGU = "Telugu"
THAI = "Thai"
TAGALOG = "Tagalog"
UKRAINIAN = "Ukrainian"
URDU = "Urdu"
XHOSA = "Xhosa"
GALICIAN = "Galician"
SLOVENE = "Slovene"



# Auto-generated. Do not modify, use scripts/generate_langs.py instead.
_PAIRS_M2M100 = (
    ("Afrikaans", "af"),
    ("Amharic", "am"),
    ("Arabic", "ar"),
    ("Asturian", "ast"),
    ("Azerbaijani", "az"),
    ("Bashkir", "ba"),
    ("Belarusian", "be"),
    ("Bulgarian", "bg"),
    ("Bengali", "bn"),
    ("Breton", "br"),
    ("Bosnian", "bs"),
    ("Catalan", "ca"),
    ("Valencian", "ca"),
    ("Cebuano", "ceb"),
    ("Czech", "cs"),
    ("Welsh", "cy"),
    ("Danish", "da"),
    ("German", "de"),
    ("Greek", "el"),
    ("English", "en"),
    ("Spanish", "es"),
    ("Estonian", "et"),
    ("Persian", "fa"),
    ("Fulah", "ff"),
    ("Finnish", "fi"),
    ("French", "fr"),
    ("Western Frisian", "fy"),
    ("Irish", "ga"),
    ("Gaelic", "gd"),
    ("Scottish Gaelic", "gd"),
    ("Galician", "gl"),
    ("Gujarati", "gu"),
    ("Hausa", "ha"),
    ("Hebrew", "he"),
    ("Hindi", "hi"),
    ("Croatian", "hr"),
    ("Haitian", "ht"),
    ("Haitian Creole", "ht"),
    ("Hungarian", "hu"),
    ("Armenian", "hy"),
    ("Indonesian", "id"),
    ("Igbo", "ig"),
    ("Iloko", "ilo"),
    ("Icelandic", "is"),
    ("Italian", "it"),
    ("Japanese", "ja"),
    ("Javanese", "jv"),
    ("Georgian", "ka"),
    ("Kazakh", "kk"),
    ("Central Khmer", "km"),
    ("Kannada", "kn"),
    ("Korean", "ko"),
    ("Luxembourgish", "lb"),
    ("Letzeburgesch", "lb"),
    ("Ganda", "lg"),
    ("Lingala", "ln"),
    ("Lao", "lo"),
    ("Lithuanian", "lt"),
    ("Latvian", "lv"),
    ("Malagasy", "mg"),
    ("Macedonian", "mk"),
    ("Malayalam", "ml"),
    ("Mongolian", "mn"),
    ("Marathi", "mr"),
    ("Malay", "ms"),
    ("Burmese", "my"),
    ("Nepali", "ne"),
    ("Dutch", "nl"),
    ("Flemish", "nl"),
    ("Norwegian", "no"),
    ("Northern Sotho", "ns"),
    ("Occitan", "oc"),
    ("Oriya", "or"),
    ("Panjabi", "pa"),
    ("Punjabi", "pa"),
    ("Polish", "pl"),
    ("Pushto", "ps"),
    ("Pashto", "ps"),
    ("Portuguese", "pt"),
    ("Romanian", "ro"),
    ("Moldavian", "ro"),
    ("Moldovan", "ro"),
    ("Russian", "ru"),
    ("Sindhi", "sd"),
    ("Sinhala", "si"),
    ("Sinhalese", "si"),
    ("Slovak", "sk"),
    ("Slovenian", "sl"),
    ("Somali", "so"),
    ("Albanian", "sq"),
    ("Serbian", "sr"),
    ("Swati", "ss"),
    ("Sundanese", "su"),
    ("Swedish", "sv"),
    ("Swahili", "sw"),
    ("Tamil", "ta"),
    ("Thai", "th"),
    ("Tagalog", "tl"),
    ("Tswana", "tn"),
    ("Turkish", "tr"),
    ("Ukrainian", "uk"),
    ("Urdu", "ur"),
    ("Uzbek", "uz"),
    ("Vietnamese", "vi"),
    ("Wolof", "wo"),
    ("Xhosa", "xh"),
    ("Yiddish", "yi"),
    ("Yoruba", "yo"),
    ("Chinese", "zh"),
    ("Zulu", "zu"),
)
_PAIRS_MBART50 = (
    ("Arabic", "ar_AR"),
    ("Czech", "cs_CZ"),
    ("German", "de_DE"),
    ("English", "en_XX"),
    ("Spanish", "es_XX"),
    ("Estonian", "et_EE"),
    ("Finnish", "fi_FI"),
    ("French", "fr_XX"),
    ("Gujarati", "gu_IN"),
    ("Hindi", "hi_IN"),
    ("Italian", "it_IT"),
    ("Japanese", "ja_XX"),
    ("Kazakh", "kk_KZ"),
    ("Korean", "ko_KR"),
    ("Lithuanian", "lt_LT"),
    ("Latvian", "lv_LV"),
    ("Burmese", "my_MM"),
    ("Nepali", "ne_NP"),
    ("Dutch", "nl_XX"),
    ("Romanian", "ro_RO"),
    ("Russian", "ru_RU"),
    ("Sinhala", "si_LK"),
    ("Turkish", "tr_TR"),
    ("Vietnamese", "vi_VN"),
    ("Chinese", "zh_CN"),
    ("Afrikaans", "af_ZA"),
    ("Azerbaijani", "az_AZ"),
    ("Bengali", "bn_IN"),
    ("Persian", "fa_IR"),
    ("Hebrew", "he_IL"),
    ("Croatian", "hr_HR"),
    ("Indonesian", "id_ID"),
    ("Georgian", "ka_GE"),
    ("Khmer", "km_KH"),
    ("Macedonian", "mk_MK"),
    ("Malayalam", "ml_IN"),
    ("Mongolian", "mn_MN"),
    ("Marathi", "mr_IN"),
    ("Polish", "pl_PL"),
    ("Pashto", "ps_AF"),
    ("Portuguese", "pt_XX"),
    ("Swedish", "sv_SE"),
    ("Swahili", "sw_KE"),
    ("Tamil", "ta_IN"),
    ("Telugu", "te_IN"),
    ("Thai", "th_TH"),
    ("Tagalog", "tl_XX"),
    ("Ukrainian", "uk_UA"),
    ("Urdu", "ur_PK"),
    ("Xhosa", "xh_ZA"),
    ("Galician", "gl_ES"),
    ("Slovene", "sl_SI"),
)
